@@ -6,5 +6,5 @@ structure(c(128.9, 137.7, 151.7, 146.5, 148.5, 163.3, 155.1,
 138.6, 145.8, 161.3, 169.3, 158.9, 149.7, 149.3, 151.3, 162, 
 167.9, 156.4, 151.2, 147.9, 157.2, 164.8, 173.6, 179.8, 198.3, 
 196.9, 191.1, 187.8, 187, 200, 197.9, 184.1, 183.1, 191, 207.9, 
-224.3, 216.1, 215.6, 229, 248.6, 290.3, 271.7, 225.7, 219.7), .Tsp = c(2000, 
-2005.91666666667, 12), class = "ts")
+224.3, 216.1, 215.6, 229, 248.6, 290.3, 271.7, 225.7, 218.5, 
+231.6, 228), .Tsp = c(2000, 2006.08333333333, 12), class = "ts")
